@@ -3,11 +3,9 @@ package Myriad::Exception::InternalError;
 use strict;
 use warnings;
 
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 our $AUTHORITY = 'cpan:DERIV'; # AUTHORITY
 
-no indirect qw(fatal);
-
 use utf8;
 
 =encoding utf8
@@ -22,13 +20,16 @@ See L<Myriad::Exception> for the rôle that defines the exception API.
 
 =cut
 
-use base qw(Myriad::Exception::Base);
+no indirect qw(fatal);
+
+use parent qw(Myriad::Exception::Base);
 
 use Role::Tiny::With;
 
 with 'Myriad::Exception';
 
 sub category { 'internal' }
+
 sub message { shift->{message} //= 'Internal error' }
 
 1;
