@@ -1,16 +1,10 @@
 package Myriad::RPC::Message;
 
-use strict;
-use warnings;
+use Myriad::Class;
 
-our $VERSION = '0.004'; # VERSION
+our $VERSION = '0.005'; # VERSION
 our $AUTHORITY = 'cpan:DERIV'; # AUTHORITY
 
-use Object::Pad;
-class Myriad::RPC::Message;
-
-use utf8;
-
 =encoding utf8
 
 =head1 NAME
@@ -255,3 +249,13 @@ sub apply_decoding ($data, $encoding) {
 
 1;
 
+=head1 AUTHOR
+
+Deriv Group Services Ltd. C<< DERIV@cpan.org >>.
+
+See L<Myriad/CONTRIBUTORS> for full details.
+
+=head1 LICENSE
+
+Copyright Deriv Group Services Ltd 2020-2021. Licensed under the same terms as Perl itself.
+
